@@ -3,6 +3,20 @@ from tensorflow.keras.models import Model
 
 
 def model_rep(top, acti_size):
+    """
+    Build a model for classifying the generated HipoMap into Cancer/Normal.
+
+    Parameters
+    ----------
+    top: int
+        The number of top patches which wanted to deal with K.
+    acti_size: int
+        The width of HipoMap ndarray.
+        The activation map size of the last conv layer from model which generated HipoMap (activation map's width * height).
+    Returns
+    -------
+
+    """
     input_ = Input(shape=(top, acti_size, 1))
     out = Conv2D(128, kernel_size=(2, 2), activation='relu')(input_)
     out = AveragePooling2D(pool_size=(2, 2))(out)
